@@ -2,23 +2,7 @@
 # $Date: 2008-05-24 17:04:16 +0200 (sam, 24 mai 2008) $
 # $Revision: 836 $
 
-#    Copyright (c) 2008-2009 Dominique Dumont.
-#
-#    This file is part of Config-Model-OpenSsh.
-#
-#    Config-Xorg is free software; you can redistribute it and/or
-#    modify it under the terms of the GNU Lesser Public License as
-#    published by the Free Software Foundation; either version 2.1 of
-#    the License, or (at your option) any later version.
-#
-#    Config-Xorg is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#    Lesser Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser Public License
-#    along with Config-Model; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+# See license at bottom of pod
 
 package Config::Model::OpenSsh ;
 
@@ -34,7 +18,7 @@ use File::Path ;
 use Parse::RecDescent ;
 use vars qw($VERSION $grammar $parser)  ;
 
-$VERSION = '1.205' ;
+$VERSION = '1.206' ;
 
 
 my $logger = Log::Log4perl::get_logger(__PACKAGE__);
@@ -527,6 +511,26 @@ sub write_host_block {
 
 Dominique Dumont, (ddumont at cpan dot org)
 
+=head1 LICENSE
+
+   Copyright (c) 2008-2009 Dominique Dumont.
+
+   This file is part of Config-Model-OpenSsh.
+
+   Config-Model-OpenSsh is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser Public License as
+   published by the Free Software Foundation; either version 2.1 of
+   the License, or (at your option) any later version.
+
+   Config-Xorg is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser Public License for more details.
+
+   You should have received a copy of the GNU Lesser Public License
+   along with Config-Model; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+
 =head1 SEE ALSO
 
-L<config-edit-sshd>, L<Config::Model>,
+L<config-edit-sshd>, L<config-edit-ssh>, L<Config::Model>,
