@@ -60,7 +60,7 @@
                                          'clientspecified' => 'allow the client to select the address to which the forwarding is bound',
                                          'no' => 'No port forwarding'
                                        },
-                             'built_in' => 'no',
+                             'upstream_default' => 'no',
                              'type' => 'leaf',
                              'description' => 'Specifies whether remote hosts are allowed to connect to ports forwarded for the client.  By default, sshd(8) binds remote port forwardings to the loopback address.  This prevents other remote hosts from connecting to forwarded ports.  GatewayPorts can be used to specify that sshd should allow remote port forwardings to bind to non-loopback addresses, thus allowing other hosts to connect.',
                              'choice' => [
@@ -79,7 +79,7 @@
                                             'allow_override' => '1'
                                           },
                              'value_type' => 'enum',
-                             'built_in' => 'no',
+                             'upstream_default' => 'no',
                              'type' => 'leaf',
                              'description' => 'Specifies whether user authentication based on GSSAPI is allowed. Note that this option applies to protocol version 2 only.',
                              'choice' => [
@@ -97,7 +97,7 @@
                                             'allow_override' => '1'
                                           },
                              'value_type' => 'enum',
-                             'built_in' => 'no',
+                             'upstream_default' => 'no',
                              'type' => 'leaf',
                              'description' => 'No doc found in sshd documentation',
                              'choice' => [
@@ -115,7 +115,7 @@
                                             'allow_override' => '1'
                                           },
                              'value_type' => 'enum',
-                             'built_in' => 'no',
+                             'upstream_default' => 'no',
                              'type' => 'leaf',
                              'description' => 'Specifies whether the password provided by the user for PasswordAuthentication will be validated through the Kerberos KDC. To use this option, the server needs a Kerberos servtab which allows the verification of the KDC\'s identity. The default is "no".',
                              'choice' => [
@@ -133,7 +133,7 @@
                                             'allow_override' => '1'
                                           },
                              'value_type' => 'enum',
-                             'built_in' => 'no',
+                             'upstream_default' => 'no',
                              'type' => 'leaf',
                              'description' => 'Specifies whether password authentication is allowed.',
                              'choice' => [
@@ -160,7 +160,7 @@
                                             'allow_override' => '1'
                                           },
                              'value_type' => 'enum',
-                             'built_in' => 'no',
+                             'upstream_default' => 'no',
                              'type' => 'leaf',
                              'description' => 'Specifies whether rhosts or /etc/hosts.equiv authentication together with successful RSA host authentication is allowed.  The default is "no". This option applies to protocol version 1 only.',
                              'choice' => [
@@ -178,7 +178,7 @@
                                             'allow_override' => '1'
                                           },
                              'value_type' => 'enum',
-                             'built_in' => 'yes',
+                             'upstream_default' => 'yes',
                              'type' => 'leaf',
                              'description' => 'Specifies whether pure RSA authentication is allowed. This option applies to protocol version 1 only.',
                              'choice' => [
@@ -196,7 +196,7 @@
                                             'allow_override' => '1'
                                           },
                              'value_type' => 'integer',
-                             'built_in' => '10',
+                             'upstream_default' => '10',
                              'type' => 'leaf',
                              'description' => 'Specifies the first display number available for sshd(8)\'s X11 forwarding. This prevents sshd from interfering with real X11 servers.'
                            },
@@ -210,7 +210,7 @@
                                             'allow_override' => '1'
                                           },
                              'value_type' => 'enum',
-                             'built_in' => 'no',
+                             'upstream_default' => 'no',
                              'type' => 'leaf',
                              'description' => 'Specifies whether X11 forwarding is permitted. Note that disabling X11 forwarding does not prevent users from forwarding X11 traffic, as users can always install their own forwarders. X11 forwarding is automatically disabled if UseLogin is enabled.',
                              'choice' => [
@@ -228,7 +228,7 @@
                                             'allow_override' => '1'
                                           },
                              'value_type' => 'enum',
-                             'built_in' => 'yes',
+                             'upstream_default' => 'yes',
                              'type' => 'leaf',
                              'description' => 'Specifies whether sshd(8) should bind the X11 forwarding server to the loopback address or to the wildcard address.  By default, sshd binds the forwarding server to the loopback address and sets the hostname part of the DISPLAY environment variable to "localhost". This prevents remote hosts from connecting to the proxy display.  However, some older X11 clients may not function with this configuration. X11UseLocalhost may be set to "no" to specify that the forwarding server should be bound to the wildcard address.',
                              'choice' => [
